==> openGion_dev_5.8.7.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GEA11S.sql <==
/****************************************************************************/
/* GEA11 ( 画面定義 )                                                       */
/*                                                                          */
/* Created : 2014/12/16 09:05:42                                            */
/****************************************************************************/
CREATE TABLE GEA11 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , SEQNO            NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  20 表示順   */
 , GUIKEY           VARCHAR2 (   30 )                   NOT NULL            /*  30 画面ID   */
 , GUILVL           VARCHAR2 (    1 )       DEFAULT '3' NOT NULL            /*  40 画面Lv   */
 , LABEL_CLM        VARCHAR2 (   30 )                                       /*  45 ﾗﾍﾞﾙｶﾗﾑ  */
 , GROUPS           VARCHAR2 (  500 )                                       /*  50 ｸﾞﾙｰﾌﾟｽ  */
 , NAME_JA          VARCHAR2 (  200 )                                       /*  60 名称     */
 , ADDRESS          VARCHAR2 (  256 )                                       /*  70 ｱﾄﾞﾚｽ    */
 , ROLES            VARCHAR2 ( 1000 )                                       /*  80 ﾛｰﾙｽﾞ    */
 , RWMODE           VARCHAR2 (    3 )                                       /*  90 ﾓｰﾄﾞ     */
 , TARGET           VARCHAR2 (   10 )                                       /* 100 ﾀｰｹﾞｯﾄ   */
 , PARAM            VARCHAR2 (  500 )                                       /* 110 設定値   */
 , KBLINK           VARCHAR2 (   10 )                                       /* 120 ﾘﾝｸ区分  */
 , COMMENTS         VARCHAR2 (  500 )                                       /* 130 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR2 (    1 )                                       /* 140 改廃ｺｰﾄﾞ */
 , KBSAKU           VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 150 作成区分 */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /* 160 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR2 (   20 )                                       /* 170 設変番号 */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成社員 */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GEA11S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GEA11T00 
  BEFORE INSERT ON GEA11
  FOR EACH ROW 
  BEGIN 
    SELECT GEA11S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_dev_5.9.2.0.zip: opengion/uap/webapps/ge/db/oracle/sql/install/01_TABLE/GEA11S.sql <==
/****************************************************************************/
/* GEA11 ( 画面定義 )                                                       */
/*                                                                          */
/* Created : 2015/10/28 15:14:26                                            */
/****************************************************************************/
CREATE TABLE GEA11 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , SEQNO            NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  20 表示順   */
 , GUIKEY           VARCHAR2 (   30 )                   NOT NULL            /*  30 画面ID   */
 , GUILVL           VARCHAR2 (    1 )       DEFAULT '3' NOT NULL            /*  40 画面Lv   */
 , LABEL_CLM        VARCHAR2 (   30 )                                       /*  45 ﾗﾍﾞﾙｶﾗﾑ  */
 , GROUPS           VARCHAR2 (  500 )                                       /*  50 ｸﾞﾙｰﾌﾟｽ  */
 , NAME_JA          VARCHAR2 (  200 )                                       /*  60 名称     */
 , ADDRESS          VARCHAR2 (  256 )                                       /*  70 ｱﾄﾞﾚｽ    */
 , ROLES            VARCHAR2 ( 1000 )                                       /*  80 ﾛｰﾙｽﾞ    */
 , RWMODE           VARCHAR2 (    3 )                                       /*  90 ﾓｰﾄﾞ     */
 , TARGET           VARCHAR2 (   10 )                                       /* 100 ﾀｰｹﾞｯﾄ   */
 , PARAM            VARCHAR2 (  500 )                                       /* 110 設定値   */
 , KBLINK           VARCHAR2 (   10 )                                       /* 120 ﾘﾝｸ区分  */
 , COMMENTS         VARCHAR2 (  500 )                                       /* 130 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR2 (    1 )                                       /* 140 改廃ｺｰﾄﾞ */
 , KBSAKU           VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 150 作成区分 */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /* 160 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR2 (   20 )                                       /* 170 設変番号 */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成社員 */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GEA11S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GEA11T00 
  BEFORE INSERT ON GEA11
  FOR EACH ROW 
  BEGIN 
    SELECT GEA11S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
